parse_response

Function parse_response 

pub fn parse_response(input: &str) -> Option<HashMap<Arc<str>, Response>>
Parse formatted model output into a map from key to Response.

Returns None if no valid keys or items are found.